Type Definition frame::runtime::types_common::Signature
source · pub type Signature = MultiSignature;Expand description
A signature type compatible capably of handling multiple crypto-schemes.
pub type Signature = MultiSignature;A signature type compatible capably of handling multiple crypto-schemes.